# Generated by Django 5.1 on 2024-09-09 20:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0046_auto_20240829_0250"),
    ]

    operations = [
        migrations.CreateModel(
            name="ImpSubstitutions",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField()),
                ("original_id", models.UUIDField(null=True)),
                ("sid", models.IntegerField(null=True, verbose_name="Original SID")),
                (
                    "dispensed_sid",
                    models.IntegerField(null=True, verbose_name="Dispensed SID"),
                ),
                (
                    "arm_match",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_evaluated", "Not evaluated"),
                        ],
                        default="not_evaluated",
                        max_length=15,
                    ),
                ),
                ("allocated_datetime", models.DateTimeField(null=True)),
                ("user_created", models.CharField(max_length=25)),
                ("user_modified", models.CharField(max_length=25)),
                ("modified", models.DateTimeField(null=True)),
            ],
            options={
                "verbose_name": "IMP Substitutions",
                "verbose_name_plural": "IMP Substitutions",
                "db_table": "imp_subjectitutions_view",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
    ]
