# Generated by Django 5.0.8 on 2024-08-19 19:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0022_auto_20240819_1832"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="endpoints",
            index=models.Index(
                fields=["subject_identifier", "site"], name="meta_report_subject_a56b22_idx"
            ),
        ),
    ]
