# Generated by Django 5.0.1 on 2024-02-13 00:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "meta_subject",
            "0166_rename_dm_medications_other_dmreferralfollowup_other_dm_medications_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="dmreferralfollowup",
            old_name="healthcare_workers_other",
            new_name="other_healthcare_workers",
        ),
        migrations.RenameField(
            model_name="historicaldmreferralfollowup",
            old_name="healthcare_workers_other",
            new_name="other_healthcare_workers",
        ),
    ]
