# Generated by Django 4.1 on 2022-08-21 18:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0138_alter_glucose_fbg_datetime_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsins",
            name="ins_units",
            field=models.CharField(
                blank=True,
                choices=[("uIU/mL", "μIU/mL")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="ins_units",
            field=models.CharField(
                blank=True,
                choices=[("uIU/mL", "μIU/mL")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
    ]
