# Generated by Django 6.0 on 2025-02-05 02:53

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_appointment", "0048_alter_appointment_site_and_more"),
        ("edc_facility", "0014_healthfacility_title_historicalhealthfacility_title"),
        ("edc_visit_schedule", "0017_alter_onschedule_managers"),
        ("meta_subject", "0218_alter_historicalnextappointment_appt_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalnextappointment",
            name="allow_create_interim",
        ),
        migrations.RemoveField(
            model_name="nextappointment",
            name="allow_create_interim",
        ),
        migrations.AddField(
            model_name="historicalnextappointment",
            name="offschedule_today",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="If going off schedule today, additional CRFs will be added for today.",
                max_length=15,
                verbose_name="Is the subject going off schedule today?",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="offschedule_today",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="If going off schedule today, additional CRFs will be added for today.",
                max_length=15,
                verbose_name="Is the subject going off schedule today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="appt_datetime",
            field=models.DateTimeField(editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="appt_datetime",
            field=models.DateTimeField(editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="health_facility",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_facility.healthfacility",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="info_source",
            field=models.ForeignKey(
                blank=True,
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="visitschedule",
            field=models.ForeignKey(
                blank=True,
                help_text="Click SAVE to let the EDC suggest. Once selected, interim appointments will be flagged as not required/missed.",
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_visit_schedule.visitschedule",
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
    ]
