# Generated by Django 4.2.11 on 2024-05-15 22:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0189_alter_dmdxresult_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If not discussed with the TMG, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If not discussed with the TMG, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_tmg",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was this case discussed with the TMG?",
            ),
        ),
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="Date of TMG discussion"
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_tmg",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was this case discussed with the TMG?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="Date of TMG discussion"
            ),
        ),
    ]
