# Generated by Django 3.2.13 on 2022-09-06 23:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0145_auto_20220907_0202"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="refill_end_datetime",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="refill_end_datetime",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
