# Generated by Django 2.2.6 on 2019-11-07 00:42

import django.core.validators
import edc_screening.model_mixins
import edc_sites.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("meta_screening", "0010_auto_20191106_0828")]

    operations = [
        migrations.AlterModelManagers(
            name="subjectscreening",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                (
                    "objects",
                    edc_screening.model_mixins.ScreeningManager(),
                ),
            ],
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="converted_fasting_glucose",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=8,
                null=True,
                verbose_name="Fasting glucose",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="fasting_glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                max_length=15,
                verbose_name="Fasting glucose units",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="converted_fasting_glucose",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=8,
                null=True,
                verbose_name="Fasting glucose",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="fasting_glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                max_length=15,
                verbose_name="Fasting glucose units",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="converted_fasting_glucose",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=8,
                null=True,
                verbose_name="Fasting glucose",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="fasting_glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                max_length=15,
                verbose_name="Fasting glucose units",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="converted_fasting_glucose",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=8,
                null=True,
                verbose_name="Fasting glucose",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="fasting_glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                max_length=15,
                verbose_name="Fasting glucose units",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="converted_fasting_glucose",
            field=models.DecimalField(
                decimal_places=4,
                help_text="mmol/L (system converted)",
                max_digits=8,
                null=True,
                verbose_name="Fasting glucose",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="fasting_glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                max_length=15,
                verbose_name="Fasting glucose units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
    ]
