# Generated by Django 5.1 on 2024-08-15 23:39

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0014_auto_20240813_1517"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endpoints",
            name="site",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.DO_NOTHING, to="sites.site"
            ),
        ),
    ]
