# Generated by Django 5.2.7 on 2025-10-14 12:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "meta_lists",
            "0020_alter_abnormalfootappearanceobservations_extra_value_and_more",
        ),
        ("meta_subject", "0237_historicalhivexitreview_singleton_field_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalhivexitreview",
            name="available",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=25,
                verbose_name="Are HIV test result and treatment information available?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivexitreview",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                help_text="May be left blank.",
                verbose_name="Any other comment?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivexitreview",
            name="not_available_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not available, please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="hivexitreview",
            name="available",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=25,
                verbose_name="Are HIV test result and treatment information available?",
            ),
        ),
        migrations.AddField(
            model_name="hivexitreview",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                help_text="May be left blank.",
                verbose_name="Any other comment?",
            ),
        ),
        migrations.AddField(
            model_name="hivexitreview",
            name="not_available_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not available, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="hivexitreview",
            name="current_arv_regimen",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="last_arv_regimen",
                to="meta_lists.arvregimens",
                verbose_name="Which antiretroviral therapy regimen is the patient currently on?",
            ),
        ),
    ]
