# Generated by Django 5.0.1 on 2024-02-13 04:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0170_remove_glucose_repeat_fbg_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("PENDING", "No. A repeat FBG will be scheduled"),
                    ("No", "No"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed",
                max_length=25,
                verbose_name="Has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If required, date particpant to repeat FBG",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("PENDING", "No. A repeat FBG will be scheduled"),
                    ("No", "No"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed",
                max_length=25,
                verbose_name="Has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If required, date particpant to repeat FBG",
            ),
        ),
    ]
