# Generated by Django 2.2.7 on 2020-01-20 17:20

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0002_auto_20191024_1000"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="other_offschedule_reason",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="other_offschedule_reason",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If OTHER, please specify",
            ),
        ),
    ]
