# Generated by Django 2.2.6 on 2019-11-07 19:49

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0006_auto_20191104_0756"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(55),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(55),
                ],
                verbose_name="ALT",
            ),
        ),
    ]
