# Generated by Django 5.0.8 on 2024-08-23 15:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0037_historicalmissingogttnote_result_status_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmissingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Did the participant fast?",
            ),
        ),
        migrations.AlterField(
            model_name="missingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Did the participant fast?",
            ),
        ),
    ]
