# Generated by Django 5.2.6 on 2025-09-29 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0067_alter_offschedule_managers_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmreferral",
            name="referral_note",
            field=models.TextField(
                default="",
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="other_offstudy_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferral",
            name="referral_note",
            field=models.TextField(
                default="",
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="other_offstudy_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="comment",
            field=models.TextField(
                default="",
                verbose_name="Please give details of the circumstances that have led to this decision.",
            ),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="home_visit_detail",
            field=models.TextField(
                default="",
                verbose_name="If YES, provide any further details of the home visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, default="", verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancynotification",
            name="unconfirmed_details",
            field=models.TextField(
                blank=True, default="", verbose_name="If no, please provide details"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="action_required_old",
            field=models.CharField(
                choices=[
                    ("remain_on_study", "Participant to remain on trial"),
                    ("to_be_withdrawn", "Participant to be withdrawn from trial"),
                    (
                        "remain_on_study_modified",
                        "Patient remains on study but data analysis will be modified",
                    ),
                ],
                default="",
                max_length=45,
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="comment",
            field=models.TextField(
                default="",
                verbose_name="Please give details of the circumstances that have led to this decision.",
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="home_visit_detail",
            field=models.TextField(
                default="",
                verbose_name="If YES, provide any further details of the home visit",
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, default="", verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="pregnancynotification",
            name="unconfirmed_details",
            field=models.TextField(
                blank=True, default="", verbose_name="If no, please provide details"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="action_required_old",
            field=models.CharField(
                choices=[
                    ("remain_on_study", "Participant to remain on trial"),
                    ("to_be_withdrawn", "Participant to be withdrawn from trial"),
                    (
                        "remain_on_study_modified",
                        "Patient remains on study but data analysis will be modified",
                    ),
                ],
                default="",
                max_length=45,
            ),
        ),
    ]
