 <a id="subject_dashboard_{{ subject_identifier }}" class="btn btn-primary btn-sm" role="button"
title="Go to subject's dashboard" href="{% url subject_dashboard_url|default:'subject_dashboard_url_cannot_be_none' subject_identifier%}">
Dashboard  <i class="fas fa-share"></i></a>
