# Generated by Django 4.2.1 on 2023-06-07 14:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0159_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="education_certificate",
            field=models.CharField(
                choices=[
                    ("primary", "Primary Certificate"),
                    ("secondary", "Secondary Certificate"),
                    ("tertiary", "post-Secondary/Tertiary/College"),
                    ("OTHER", "Other, specify ..."),
                    ("N/A", "Not applicable, never went to school"),
                ],
                max_length=50,
                null=True,
                verbose_name="What is your highest education certificate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicssimple",
            name="education_certificate",
            field=models.CharField(
                choices=[
                    ("primary", "Primary Certificate"),
                    ("secondary", "Secondary Certificate"),
                    ("tertiary", "post-Secondary/Tertiary/College"),
                    ("OTHER", "Other, specify ..."),
                    ("N/A", "Not applicable, never went to school"),
                ],
                max_length=50,
                null=True,
                verbose_name="What is your highest education certificate?",
            ),
        ),
    ]
