# Generated by Django 4.2.11 on 2024-05-15 23:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0195_alter_glucosefbg_fbg_datetime_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="glucosefbg",
            name="fbg_not_performed_reason",
            field=models.CharField(
                blank=True, max_length=150, null=True, verbose_name="If NO, provide reason"
            ),
        ),
        migrations.AddField(
            model_name="glucosefbg",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalglucosefbg",
            name="fbg_not_performed_reason",
            field=models.CharField(
                blank=True, max_length=150, null=True, verbose_name="If NO, provide reason"
            ),
        ),
        migrations.AddField(
            model_name="historicalglucosefbg",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
            preserve_default=False,
        ),
    ]
